--[[
# 显示cpu0,cpu1.men,swap,down,up,battery使用率
# 本脚本修改自著名的 clock_rings.lua
]]

settings_table = {
    -- cup0 使用率
    {
        name='cpu',
        arg='cpu0',
        max=100,
        bg_colour=0xffffff,
        bg_alpha=0.2,
        fg_colour=0x008000,
        fg_alpha=0.8,
        x=35, y=190,
        radius=25,
        thickness=4,
        start_angle=0,
        end_angle=360
    },
    -- cup1 使用率
    {
        name='cpu',
        arg='cpu1',
        max=100,
        bg_colour=0xffffff,
        bg_alpha=0.2,
        fg_colour=0x008000,
        fg_alpha=0.8,
        x=35, y=190,
        radius=20,
        thickness=4,
        start_angle=0,
        end_angle=360
    },
    -- 内存使用率
    {
        name='memperc',
        arg='',
        max=100,
        bg_colour=0xffffff,
        bg_alpha=0.2,
        fg_colour=0x008000,
        fg_alpha=0.8,
        x=97, y=190,
        radius=25,
        thickness=4,
        start_angle=0,
        end_angle=360
    },
    -- 交换使用率
    {
        name='swapperc',
        arg='',
        max=100,
        bg_colour=0xffffff,
        bg_alpha=0.2,
        fg_colour=0x008000,
        fg_alpha=0.8,
        x=97, y=190,
        radius=20,
        thickness=4,
        start_angle=0,
        end_angle=360
    },
    -- 下行数据
    {
        name='downspeedf',
        arg='enp5s0',
        max=100,
        bg_colour=0xffffff,
        bg_alpha=0.2,
        fg_colour=0x008000,
        fg_alpha=0.8,
        x=35, y=252,
        radius=25,
        thickness=4,
        start_angle=0,
        end_angle=360
    },
    -- 上行数据
    {
        name='upspeedf',
        arg='enp5s0',
        max=100,
        bg_colour=0xffffff,
        bg_alpha=0.2,
        fg_colour=0x008000,
        fg_alpha=0.8,
        x=35, y=252,
        radius=20,
        thickness=4,
        start_angle=0,
        end_angle=360
    },
    -- 电池使用率
    {
        name='battery_percent',
        arg='',
        max=100,
        bg_colour=0xffffff,
        bg_alpha=0.2,
        fg_colour=0x008000,
        fg_alpha=0.8,
        x=97, y=252,
        radius=25,
        thickness=4,
        start_angle=0,
        end_angle=360
    },
}

-- 需要 cairo 图形库
require 'cairo'

-- rgb颜色
function rgb_to_r_g_b(colour,alpha)
    return ((colour / 0x10000) % 0x100) / 255., ((colour / 0x100) % 0x100) / 255., (colour % 0x100) / 255., alpha
end

-- 绘制圆
function draw_ring(cr,t,pt)
    local w,h=conky_window.width,conky_window.height

    local xc,yc,ring_r,ring_w,sa,ea=pt['x'],pt['y'],pt['radius'],pt['thickness'],pt['start_angle'],pt['end_angle']
    local bgc, bga, fgc, fga=pt['bg_colour'], pt['bg_alpha'], pt['fg_colour'], pt['fg_alpha']

    local angle_0=sa*(2*math.pi/360)-math.pi/2
    local angle_f=ea*(2*math.pi/360)-math.pi/2
    local t_arc=t*(angle_f-angle_0)

    -- Draw background ring

    cairo_arc(cr,xc,yc,ring_r,angle_0,angle_f)
    cairo_set_source_rgba(cr,rgb_to_r_g_b(bgc,bga))
    cairo_set_line_width(cr,ring_w)
    cairo_stroke(cr)

    -- Draw indicator ring

    cairo_arc(cr,xc,yc,ring_r,angle_0,angle_0+t_arc)
    cairo_set_source_rgba(cr,rgb_to_r_g_b(fgc,fga))
    cairo_stroke(cr)        
end

-- 主函数
function conky_clock_rings()
    local function setup_rings(cr,pt)
        local str=''
        local value=0

        if pt['name'] == 'battery_percent' then
        	str='${if_existing /sys/class/power_supply/BAT0}${battery_percent BAT0}${else}${if_existing /sys/class/power_supply/BAT1}${battery_percent BAT1}${else}0${endif}${endif}'
        else
        	str=string.format('${%s %s}',pt['name'],pt['arg'])
        end
 
        str=conky_parse(str)
        value=tonumber(str)
        pct=value/pt['max']

        draw_ring(cr,pct,pt)
    end

    -- Check that Conky has been running for at least 5s

    if conky_window==nil then return end
    local cs=cairo_xlib_surface_create(conky_window.display,conky_window.drawable,conky_window.visual, conky_window.width,conky_window.height)

    local cr=cairo_create(cs)  

    local updates=conky_parse('${updates}')
    update_num=tonumber(updates)

    if update_num>5 then
        for i in pairs(settings_table) do
            setup_rings(cr,settings_table[i])
        end
    end
end
